import os
import nibabel as nib
import argparse
import numpy as np
from statistics import mean

def dice(y_true, y_pred):
    intersection = np.sum(y_true * y_pred)
    return (2. * intersection) / (np.sum(y_true) + np.sum(y_pred))

parser = argparse.ArgumentParser()
parser.add_argument('--dir_groundtruth', type=str, required= True, help="path of Ground-truth Masks")
parser.add_argument('--dir_prediction', type=str, required = True, help="path of Predicted Masks") 


if __name__ == '__main__':
    args = parser.parse_args()

    lst_prediction=os.listdir(args.dir_prediction)
    lst_prediction.sort()
    lst_dice= []

    for prediction in lst_prediction:
        patient_id = prediction.split('_')[0]

        ground_truth = nib.load(os.path.join(args.dir_groundtruth, patient_id + '/' + patient_id + '_MASK.nii.gz')).get_fdata()
        pred = nib.load(os.path.join(args.dir_prediction, prediction)).get_fdata()

       

        if(pred.shape == (182, 218, 182)): # equals to ground_truth.shape, which MUST BE (182, 218, 182)!!!
            predicted_dice = dice(ground_truth, pred)
        else:
            predicted_dice = 0

        lst_dice.append(predicted_dice)

    print(f"MEAN DICE: {mean(lst_dice)}")
        

